@@ -1326,7 +1326,7 @@ class SQLCli(object):
     # 断开数据库连接
     def disconnect_db(self, arg, **_):
         if arg:
-            return [(None, None, None, "unnecessary parameter")]
+            return [(None, None, None, None, "unnecessary parameter")]
         if self.db_conn:
             self.db_conn.close()
         self.db_conn = None
@@ -1402,13 +1402,13 @@ class SQLCli(object):
     def sleep(self, arg, **_):
         if not arg:
             message = "Missing required argument, sleep [seconds]."
-            return [(None, None, None, message)]
+            return [(None, None, None, None, message)]
         try:
             # 每次最多休息3秒钟，随后检查一下运行状态, 如果要求退出，就退出程序
             m_Sleep_Time = int(arg)
             if m_Sleep_Time <= 0:
                 message = "Parameter must be a valid number, sleep [seconds]."
-                return [(None, None, None, message)]
+                return [(None, None, None, None, message)]
             for m_nPos in range(0, int(arg)//3):
                 if self.m_Shutdown_Flag:
                     raise EOFError
@@ -1959,12 +1959,15 @@ class SQLCli(object):
             self.echo(status)
 
     def format_output_csv(self, headers, columntypes, cur):
+        # 将屏幕输出按照CSV格式进行输出
         m_csv_delimiter = self.SQLOptions.get("CSV_DELIMITER")
         m_csv_quotechar = self.SQLOptions.get("CSV_QUOTECHAR")
         if m_csv_delimiter.find("\\t") != -1:
             m_csv_delimiter = m_csv_delimiter.replace("\\t", '\t')
         if m_csv_delimiter.find("\\s") != -1:
             m_csv_delimiter = m_csv_delimiter.replace("\\s", ' ')
+
+        # 打印字段名称
         if self.SQLOptions.get("CSV_HEADER") == "ON":
             m_row = ""
             for m_nPos in range(0, len(headers)):
@@ -1973,13 +1976,17 @@ class SQLCli(object):
                     m_row = m_row + m_csv_delimiter
             yield str(m_row)
 
+        # 打印字段内容
         for row in cur:
             m_row = ""
             for m_nPos in range(0, len(row)):
-                if columntypes[m_nPos] == str:
-                    m_row = m_row + m_csv_quotechar + str(row[m_nPos]) + m_csv_quotechar
-                else:
+                if columntypes is None:
                     m_row = m_row + str(row[m_nPos])
+                else:
+                    if columntypes[m_nPos] == str:
+                        m_row = m_row + m_csv_quotechar + str(row[m_nPos]) + m_csv_quotechar
+                    else:
+                        m_row = m_row + str(row[m_nPos])
                 if m_nPos != len(row) - 1:
                     m_row = m_row + m_csv_delimiter
             yield str(m_row)
@@ -2003,6 +2010,7 @@ class SQLCli(object):
                 cur = list(cur)
 
             if p_format_name.upper() == 'CSV':
+                # 按照CSV格式输出查询结果
                 formatted = self.format_output_csv(headers, columntypes, cur)
             else:
                 formatted = self.formatter.format_output(
